package sun.security.jgss.krb5;

import java.io.OutputStream;
import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.InputStream;
import org.ietf.jgss.GSSException;
import org.ietf.jgss.MessageProp;

class MicToken_v2 extends MessageToken_v2
{
    public MicToken_v2(Krb5Context krb5Context, byte[] array, int n, int n2, MessageProp messageProp) throws GSSException {
        super(1028, krb5Context, array, n, n2, messageProp);
    }
    
    public MicToken_v2(Krb5Context krb5Context, InputStream inputStream, MessageProp messageProp) throws GSSException {
        super(1028, krb5Context, inputStream, messageProp);
    }
    
    public void verify(byte[] array, int n, int n2) throws GSSException {
        if (!this.verifySign(array, n, n2)) {
            throw new GSSException(6, -1, "Corrupt checksum or sequence number in MIC token");
        }
        return;
    }
    
    public void verify(InputStream inputStream) throws GSSException {
        byte[] b;
        try {
            b = new byte[inputStream.available()];
            inputStream.read(b);
        }
        catch (IOException ex) {
            throw new GSSException(6, -1, "Corrupt checksum or sequence number in MIC token");
        }
        this.verify(b, 0, b.length);
    }
    
    public MicToken_v2(Krb5Context krb5Context, MessageProp messageProp, byte[] array, int n, int n2) throws GSSException {
        super(1028, krb5Context);
        if (messageProp == null) {
            messageProp = new MessageProp(0, false);
        }
        this.genSignAndSeqNumber(messageProp, array, n, n2);
    }
    
    public MicToken_v2(Krb5Context krb5Context, MessageProp messageProp, InputStream inputStream) throws GSSException, IOException {
        super(1028, krb5Context);
        byte[] b = new byte[inputStream.available()];
        inputStream.read(b);
        if (messageProp == null) {
            messageProp = new MessageProp(0, false);
        }
        this.genSignAndSeqNumber(messageProp, b, 0, b.length);
    }
    
    public byte[] encode() throws IOException {
        ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream(50);
        this.encode(byteArrayOutputStream);
        return byteArrayOutputStream.toByteArray();
    }
    
    public int encode(byte[] array, int n) throws IOException {
        byte[] encode = this.encode();
        System.arraycopy(encode, 0, array, n, encode.length);
        return encode.length;
    }
    
    @Override
    public void encode(OutputStream outputStream) throws IOException {
        this.encodeHeader(outputStream);
        outputStream.write(this.checksum);
    }
}
